@@ -10,14 +10,31 @@
 #include <catch2/catch_test_case_info.hpp>
 #include <catch2/internal/catch_test_case_registry_impl.hpp>
 #include <catch2/interfaces/catch_interfaces_registry_hub.hpp>
+#include <catch2/internal/catch_string_manip.hpp>
 
 namespace Catch {
 
+    namespace {
+        std::string extractClassName( StringRef classOrQualifiedMethodName ) {
+            std::string className( classOrQualifiedMethodName );
+            if ( startsWith( className, '&' ) ) {
+                std::size_t lastColons = className.rfind( "::" );
+                std::size_t penultimateColons =
+                    className.rfind( "::", lastColons - 1 );
+                if ( penultimateColons == std::string::npos )
+                    penultimateColons = 1;
+                className = className.substr( penultimateColons,
+                                              lastColons - penultimateColons );
+            }
+            return className;
+        }
+    } // namespace
+
     Detail::unique_ptr<ITestInvoker> makeTestInvoker( void(*testAsFunction)() ) {
-        return Detail::unique_ptr<ITestInvoker>( new TestInvokerAsFunction( testAsFunction ));
+        return Detail::make_unique<TestInvokerAsFunction>( testAsFunction );
     }
 
-    AutoReg::AutoReg( Detail::unique_ptr<ITestInvoker> invoker, SourceLineInfo const& lineInfo, StringRef const& classOrMethod, NameAndTags const& nameAndTags ) noexcept {
+    AutoReg::AutoReg( Detail::unique_ptr<ITestInvoker> invoker, SourceLineInfo const& lineInfo, StringRef classOrMethod, NameAndTags const& nameAndTags ) noexcept {
         CATCH_TRY {
             getMutableRegistryHub()
                     .registerTest(
