@@ -3,6 +3,8 @@
 #include <spdlog/spdlog.h>
 #include <tins/tins.h>
 
+#include <boost/iostreams/device/file.hpp>
+#include <boost/iostreams/filter/zstd.hpp>
 #include <caracal/parser.hpp>
 #include <caracal/sniffer.hpp>
 #include <caracal/statistics.hpp>
@@ -12,6 +14,7 @@
 #include <optional>
 #include <thread>
 
+namespace io = boost::iostreams;
 namespace fs = std::filesystem;
 
 namespace caracal {
@@ -27,25 +30,32 @@ Sniffer::Sniffer(const std::string &interface_name,
       caracal_id_{caracal_id},
       integrity_check_{integrity_check} {
   Tins::NetworkInterface interface{interface_name};
-  auto filter = fmt::format(
-      "(dst {} or dst {}) and ((icmp and icmp[icmptype] != icmp-echo) or "
-      "(icmp6 and icmp6[icmp6type] != icmp6-echo))",
-      Utilities::source_ipv4_for(interface).to_string(),
-      Utilities::source_ipv6_for(interface).to_string());
+  auto filter_template =
+      "(dst {} or dst {}) and (icmp or icmp6) and ("
+      "icmp[icmptype] = icmp-echoreply or"
+      " icmp[icmptype] = icmp-timxceed or"
+      " icmp[icmptype] = icmp-unreach or"
+      " icmp6[icmp6type] = icmp6-echoreply or"
+      " icmp6[icmp6type] = icmp6-timeexceeded or"
+      " icmp6[icmp6type] = icmp6-destinationunreach"
+      ")";
+  auto filter = fmt::format(filter_template,
+                            Utilities::source_ipv4_for(interface).to_string(),
+                            Utilities::source_ipv6_for(interface).to_string());
   spdlog::info("sniffer_filter={}", filter);
 
   Tins::SnifferConfiguration config;
-  // TODO: What happens the buffer is full?
-  // TODO: Log buffer full / dropped packets?
-  config.set_buffer_size(32 * 1024 * 1024);
+  config.set_buffer_size(64 * 1024 * 1024);
   config.set_filter(filter);
   config.set_immediate_mode(true);
-
-  // As sniffer does not have set_configuration, we copy...
   sniffer_ = Tins::Sniffer(interface_name, config);
 
   if (output_file_csv) {
-    output_csv_.open(*output_file_csv);
+    output_csv_ofs_.open(*output_file_csv);
+    if (output_file_csv->extension() == ".zst") {
+      output_csv_.push(io::zstd_compressor(1));
+    }
+    output_csv_.push(output_csv_ofs_);
   }
 
   if (output_file_pcap) {
@@ -100,4 +110,10 @@ const Statistics::Sniffer &Sniffer::statistics() const noexcept {
   return statistics_;
 }
 
+pcap_stat Sniffer::pcap_statistics() noexcept {
+  pcap_stat ps{};
+  pcap_stats(sniffer_.get_pcap_handle(), &ps);
+  return ps;
+};
+
 }  // namespace caracal
